@@ -578,94 +578,3 @@ setMethod(f = "plot", signature = "Clere", definition = function(x, ...) {
         stop("[Clere:plot] SEM iterations is below 2", call. = FALSE)
     }
 })
-
-
-### GGPlot ###
-setGeneric(name = "ggPlot", def = function(data, ...) {standardGeneric("ggPlot")})
-setMethod(f = "ggPlot", signature = "Clere", definition = function(data, ...) {
-    is.installed <- function(mypkg) {
-        is.element(mypkg, installed.packages()[,1])
-    }
-    if (all(is.installed(c("ggplot2", "grid")))) {
-        require(ggplot2)
-        require(grid)
-    } else {
-        stop("[Clere:ggPlot] \"ggPlot2\" and \"grid\" packages must be installed", call. = FALSE)
-    }
-    
-    multiplot <- function (plotlist = NULL, cols = 1, rows = 1, layout = NULL) {
-        plots <- plotlist
-        numPlots = length(plots)
-        if (is.null(layout)) {
-            layout <- matrix(seq(1, cols * ceiling(numPlots/cols)), ncol = cols, nrow = rows, byrow = TRUE)
-        } else {}
-        if (numPlots == 1) {
-            print(plots[[1]])
-        } else {
-            grid.newpage()
-            pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
-            for (i in seq(numPlots)) {
-                matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
-                print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row, layout.pos.col = matchidx$col))
-            }
-        }
-    }
-    ggplotColours <- function(n = 6, h = c(0, 360) + 15) {
-            if ((diff(h)%%360) < 1) {
-                h[2] <- h[2] - 360/n
-            } else {}
-            hcl(h = (seq(h[1], h[2], length = n)), c = 100, l = 65)
-        }
-
-    nbrow <- nrow(data@theta)
-    if (nbrow >= 2) {
-        K <- length(data@b)
-        sK <- seq(K)
-        xlabname <- paste(data@algorithm, "iterations")
-        seqnrow <- seq(nbrow)
-        cnames <- colnames(data@theta)
-        
-        ### First plot
-        dataTmp <- cbind(rep(seqnrow, length(1+(sK))), rep(cnames[1+(sK)], each = nbrow), as.data.frame(matrix(data@theta[, 1+(sK)], ncol = 1)))
-        colnames(dataTmp) <- c("x", "b", "values")
-        p1 <- eval(parse(text = paste0("ggplot(data = dataTmp, aes(x = x, y = values, colour = b)) + geom_line() + geom_vline(xintercept = data@nBurn, colour = \"grey\")")))
-        p1 <- p1 + labs(x = xlabname, y = "The b's") # labs' name, "title" can be added
-        p1 <- p1 + theme(legend.position = "none") # remove legend
-        p1 <- p1 + scale_colour_manual(values = ggplotColours(length(1+(sK)))) # color palette
-        
-        ### Second plot
-        dataTmp <- cbind(rep(seqnrow, length(1+K+(sK))), rep(cnames[1+K+(sK)], each = nbrow), as.data.frame(matrix(data@theta[, 1+K+(sK)], ncol = 1)))
-        colnames(dataTmp) <- c("x", "pi", "values")
-        p2 <- eval(parse(text = paste0("ggplot(data = dataTmp, aes(x = x, y = values, colour = pi)) + geom_line() + geom_vline(xintercept = data@nBurn, colour = \"grey\")")))
-        p2 <- p2 + labs(x = xlabname, y = "The pi's") # labs' name, "title" can be added
-        p2 <- p2 + theme(legend.position = "none") # remove legend
-        p2 <- p2 + scale_colour_manual(values = ggplotColours(length(1+K+(sK)))) # color palette
-        
-        ### Third plot
-        dataTmp <- cbind(rep(seqnrow, length(c(2*K+2,2*K+3))), rep(cnames[c(2*K+2,2*K+3)], each = nbrow), as.data.frame(matrix(data@theta[, c(2*K+2,2*K+3)], ncol = 1)))
-        colnames(dataTmp) <- c("x", "sg", "values")
-        p3 <- eval(parse(text = paste0("ggplot(data = dataTmp, aes(x = x, y = values, colour = sg)) + geom_line() + geom_vline(xintercept = data@nBurn, colour = \"grey\")")))
-        p3 <- p3 + labs(x = xlabname, y = "sigma^2 and gamma^2") # labs' name, "title" can be added
-        p3 <- p3 + scale_colour_manual(values = ggplotColours(length(c(2*K+2,2*K+3)))) # color palette        
-        p3 <- p3 + ylim(c(0.5*min(data@theta[, c(2*K+2,2*K+3)], na.rm = TRUE), 1.5*max(data@theta[, c(2*K+2,2*K+3)], na.rm = TRUE))) # ylim
-        # tmpSigGam <- range(dataTmp[, "values"])
-        # tmpSigma2 <- range(dataTmp[dataTmp$sg == "sigma2", "values"][(nbrow*2/3):nbrow])
-        # if ((abs(tmpSigma2[2]-tmpSigGam[2])/tmpSigGam[2]) >= 0.70) {
-            p3 <- p3 + theme(legend.title = element_blank(), legend.justification = c(1, 1), legend.position = c(1, 1)) # legend aspect and position
-        # } else {
-            # p3 <- p3 + theme(legend.title = element_blank(), legend.justification = c(1, 1), legend.position = c(1, tmpSigma2[1]/tmpSigGam[2])) # legend aspect and position
-        # }
-
-        ### Fourth plot
-        dataTmp <- cbind(seqnrow, as.data.frame(data@theta[, 1]))
-        colnames(dataTmp) <- c("x", "intercept")
-        p4 <- eval(parse(text = paste0("ggplot(data = dataTmp, aes(x = x, y = intercept)) + geom_line(colour = ggplotColours(1)) + geom_vline(xintercept = data@nBurn, colour = \"grey\")")))
-        p4 <- p4 + labs(x = xlabname, y = "Intercept")
-        
-        allPlots <- list(p1, p2, p3, p4)
-        multiplot(plotlist = allPlots, cols = 2, rows = 2) # All plots in the same device
-        invisible(allPlots)
-    } else {
-        stop("[Clere:plot] SEM iterations is below 2", call. = FALSE)
-    }
-})
